==> adfurikun-1.0.1.tar.gz: example/lib/banner_sample.dart <==
import 'dart:io';

import 'package:adfurikun/banner.dart';
import 'package:adfurikun_example/constants.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';

class BannerPage extends StatefulWidget {
  BannerPage({Key? key}) : super(key: key);
  @override
  BannerPageState createState() => BannerPageState();
}

class BannerPageState extends State<BannerPage> with WidgetsBindingObserver {

  late AdfurikunBanner banner;

  double width = 320;
  double height = 50;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Banner Sample"),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => load(),
                    child: Text("Load")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => show(),
                    child: Text("Show")
                )
            ),
            Container(
                width: width,
                height: height,
                child: banner.adWidget()
            )
          ],
        ),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance?.addObserver(this);
    String appId = "";
    if (Platform.isAndroid) {
      appId = ANDROID_BANNER_APPID;
    } else {
      appId = IOS_BANNER_APPID;
    }
    banner = AdfurikunBanner(appId, width, height);
    banner.listener = notifyCallback;
  }

  @override
  void dispose() {
    super.dispose();
    WidgetsBinding.instance?.removeObserver(this);
    banner.destroy();
    banner.listener = null;
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (AppLifecycleState.resumed == state) {
      banner.resume();
    } else if (AppLifecycleState.paused == state) {
      banner.pause();
    }
  }

  void load() {
    banner.load();
  }

  void show() {
    banner.play();
  }

  void notifyCallback(AdfurikunBannerCallback? callback, String? appId, String? adNetworkKey,
      String? title, String? description, int? errorCode) {
    if (AdfurikunBannerCallback.onBannerLoadFinish == callback) {
      Fluttertoast.showToast(msg: "読み込み成功");
    } else if (AdfurikunBannerCallback.onBannerLoadError == callback) {
      Fluttertoast.showToast(msg: "読み込み失敗");
    } else if (AdfurikunBannerCallback.onBannerViewPlayStart == callback) {
      Fluttertoast.showToast(msg: "再生開始");
    } else if (AdfurikunBannerCallback.onBannerViewPlayFinish == callback) {
      Fluttertoast.showToast(msg: "再生終了");
    } else if (AdfurikunBannerCallback.onBannerViewPlayFail == callback) {
      Fluttertoast.showToast(msg: "再生失敗");
    } else if (AdfurikunBannerCallback.onBannerViewClicked == callback) {
      Fluttertoast.showToast(msg: "広告クリック");
    }
  }
}

==> adfurikun-1.5.0.tar.gz: example/lib/banner_sample.dart <==
import 'dart:io';

import 'package:adfurikun/banner.dart';
import 'package:adfurikun_example/constants.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';

class BannerPage extends StatefulWidget {
  BannerPage({Key? key}) : super(key: key);
  @override
  BannerPageState createState() => BannerPageState();
}

class BannerPageState extends State<BannerPage> {

  late AdfurikunBanner banner;

  double width = 320;
  double height = 50;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Banner Sample"),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => load(),
                    child: Text("Load")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => show(),
                    child: Text("Show")
                )
            ),
            Container(
                width: width,
                height: height,
                child: banner.adWidget()
            )
          ],
        ),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    String appId = "";
    if (Platform.isAndroid) {
      appId = ANDROID_BANNER_APPID;
    } else {
      appId = IOS_BANNER_APPID;
    }
    banner = AdfurikunBanner(appId, width, height);
    banner.listener = notifyCallback;
  }

  @override
  void dispose() {
    super.dispose();
    banner.destroy();
    banner.listener = null;
  }

  void load() {
    banner.load();
  }

  void show() {
    banner.play();
  }

  void notifyCallback(AdfurikunBannerCallback? callback, String? appId, String? adNetworkKey,
      String? title, String? description, int? errorCode) {
    if (AdfurikunBannerCallback.onBannerLoadFinish == callback) {
      Fluttertoast.showToast(msg: "読み込み成功");
    } else if (AdfurikunBannerCallback.onBannerLoadError == callback) {
      Fluttertoast.showToast(msg: "読み込み失敗");
    } else if (AdfurikunBannerCallback.onBannerViewPlayStart == callback) {
      Fluttertoast.showToast(msg: "再生開始");
    } else if (AdfurikunBannerCallback.onBannerViewPlayFinish == callback) {
      Fluttertoast.showToast(msg: "再生終了");
    } else if (AdfurikunBannerCallback.onBannerViewPlayFail == callback) {
      Fluttertoast.showToast(msg: "再生失敗");
    } else if (AdfurikunBannerCallback.onBannerViewClicked == callback) {
      Fluttertoast.showToast(msg: "広告クリック");
    }
  }
}
